@@ -1,9 +1,9 @@
 #ifndef GaMaLib___language__header_file_h
 #define GaMaLib___language__header_file_h
 
-namespace GaMaLib {      /* slovnikar 1.03 */
+namespace GaMaLib {      /* slovnikar 1.05 */
 
-enum gama_language { en, cz, fi, du };
+enum gama_language { en, cz, fi, du, hu, ca };
 void set_gama_language(gama_language);
 
 extern const char* T_GKF_bad_angle;
@@ -179,9 +179,11 @@ extern const char* T_GaMa_network_description;
 extern const char* T_GaMa_not_enough_constrained_points;
 extern const char* T_GaMa_point;
 extern const char* T_GaMa_reduced_Review_of_reduced_observations;
+extern const char* T_GaMa_reduced_Review_of_reduced_observations_to_ellipsoid;
 extern const char* T_GaMa_reduced_header1;
 extern const char* T_GaMa_reduced_observed;
 extern const char* T_GaMa_reduced_reduced;
+extern const char* T_GaMa_reduced_to_ellipsoid_header1;
 extern const char* T_GaMa_reduced_value;
 extern const char* T_GaMa_resobs_Outlying_observations;
 extern const char* T_GaMa_resobs_Review_of_residuals_analysis_obs;
