@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adjusted_unknowns.h,v 1.8 2004/03/18 17:07:01 cepek Exp $
+ *  $Id: adjusted_unknowns.h,v 1.9 2004/06/20 20:54:51 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Vyrovnane_Nezname_h_
@@ -32,7 +32,7 @@
 
 namespace GaMaLib {
 
-template <class OutStream>
+template <typename OutStream>
 void AdjustedUnknowns(GaMaLib::LocalNetwork* IS, OutStream& out)
 {
   using namespace std;
