@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: olsgso.h,v 1.3 2004/08/29 18:01:52 cepek Exp $
+ *  $Id: olsgso.h,v 1.4 2005/03/27 17:43:26 cepek Exp $
  */
 
 #ifndef GaMa_OLS_gso_h
@@ -38,42 +38,42 @@ class OLSgso : public virtual BaseOLS<Float, Exc> {
 public:
 
   OLSgso() {}
-  OLSgso(const gMatVec::Mat<Float, Exc>& A, const gMatVec::Vec<Float, Exc>& b)
+  OLSgso(const GNU_gama::Mat<Float, Exc>& A, const GNU_gama::Vec<Float, Exc>& b)
     : BaseOLS<Float, Exc>(A, b) {}
-  OLSgso(const gMatVec::Mat<Float, Exc>& A, const gMatVec::Vec<Float, Exc>& b,
-         const gMatVec::Vec<Float, Exc>& w) : BaseOLS<Float, Exc>(A, b, w) {}
+  OLSgso(const GNU_gama::Mat<Float, Exc>& A, const GNU_gama::Vec<Float, Exc>& b,
+         const GNU_gama::Vec<Float, Exc>& w) : BaseOLS<Float, Exc>(A, b, w) {}
   
-  void reset(const gMatVec::Mat<Float, Exc>& A, 
-             const gMatVec::Vec<Float, Exc>& b)
+  void reset(const GNU_gama::Mat<Float, Exc>& A, 
+             const GNU_gama::Vec<Float, Exc>& b)
     {
       BaseOLS<Float, Exc>::reset(A, b);
     }
-  void reset(const gMatVec::Mat<Float, Exc>& A, 
-             const gMatVec::Vec<Float, Exc>& b,
-             const gMatVec::Vec<Float, Exc>& w)
+  void reset(const GNU_gama::Mat<Float, Exc>& A, 
+             const GNU_gama::Vec<Float, Exc>& b,
+             const GNU_gama::Vec<Float, Exc>& w)
     {
       BaseOLS<Float, Exc>::reset(A, b, w);
     }
   
-  const gMatVec::Vec<Float, Exc>& solve(gMatVec::Vec<Float, Exc>& x)
+  const GNU_gama::Vec<Float, Exc>& solve(GNU_gama::Vec<Float, Exc>& x)
     {
       return x = BaseOLS<Float, Exc>::solve();
     }
-  const gMatVec::Vec<Float, Exc>& solve() 
+  const GNU_gama::Vec<Float, Exc>& solve() 
     { 
       return BaseOLS<Float, Exc>::solve(); 
     }
   
-  gMatVec::Index defect() { return gso.defect(); }
-  bool  lindep(gMatVec::Index i) { return gso.lindep(i); }
+  GNU_gama::Index defect() { return gso.defect(); }
+  bool  lindep(GNU_gama::Index i) { return gso.lindep(i); }
   
-  void  q_xx(gMatVec::Mat<Float, Exc>& C) { BaseOLS<Float, Exc>::q_xx(C); }
-  Float q_xx(gMatVec::Index i, gMatVec::Index j);
-  Float q_bb(gMatVec::Index i, gMatVec::Index j);
-  Float q_bx(gMatVec::Index i, gMatVec::Index j);
+  void  q_xx(GNU_gama::Mat<Float, Exc>& C) { BaseOLS<Float, Exc>::q_xx(C); }
+  Float q_xx(GNU_gama::Index i, GNU_gama::Index j);
+  Float q_bb(GNU_gama::Index i, GNU_gama::Index j);
+  Float q_bx(GNU_gama::Index i, GNU_gama::Index j);
   
   void min_x() { gso.min_x(); }
-  void min_x(gMatVec::Index n, gMatVec::Index x[]) { gso.min_x(n, x); }
+  void min_x(GNU_gama::Index n, GNU_gama::Index x[]) { gso.min_x(n, x); }
   
   
 protected:
@@ -82,8 +82,8 @@ protected:
    
 private:
 
-   gMatVec::Mat<Float, Exc> A_;
-   gMatVec::GSO<Float, Exc> gso;
+   GNU_gama::Mat<Float, Exc> A_;
+   GNU_gama::GSO<Float, Exc> gso;
 
    void init_gso_();
 };
@@ -96,8 +96,8 @@ void OLSgso<Float, Exc>::solve_me()
 {
   if (this->is_solved) return;
 
-  const gMatVec::Index M = this->pA->rows();
-  const gMatVec::Index N = this->pA->cols();
+  const GNU_gama::Index M = this->pA->rows();
+  const GNU_gama::Index N = this->pA->cols();
   
   A_.reset(M+N, N+1);
   this->sqrt_w.reset(M);
@@ -105,27 +105,27 @@ void OLSgso<Float, Exc>::solve_me()
   if (this->pw)
     {
       using namespace std;
-      const gMatVec::Vec<Float, Exc>& w_ = *this->pw;
-      for (gMatVec::Index i=1; i<=M; i++) this->sqrt_w(i) = sqrt(w_(i));
+      const GNU_gama::Vec<Float, Exc>& w_ = *this->pw;
+      for (GNU_gama::Index i=1; i<=M; i++) this->sqrt_w(i) = sqrt(w_(i));
     }
   else
     {
-      for (gMatVec::Index i=1; i<=M; i++) this->sqrt_w(i) = 1;
+      for (GNU_gama::Index i=1; i<=M; i++) this->sqrt_w(i) = 1;
     }
 
-  const gMatVec::Mat<Float, Exc>& A1 = *this->pA;
-  const gMatVec::Vec<Float, Exc>& b1 = *this->pb;
+  const GNU_gama::Mat<Float, Exc>& A1 = *this->pA;
+  const GNU_gama::Vec<Float, Exc>& b1 = *this->pb;
 
   {  // redundant curly braces needed by MS VC++ 
-  for (gMatVec::Index i=1; i<=M; i++)
+  for (GNU_gama::Index i=1; i<=M; i++)
     {
       A_(i, N+1) = -b1(i)*this->sqrt_w(i);
-      for (gMatVec::Index j=1; j<=N; j++) A_(i, j) = A1(i, j)*this->sqrt_w(i);
+      for (GNU_gama::Index j=1; j<=N; j++) A_(i, j) = A1(i, j)*this->sqrt_w(i);
     }
   }
   {
-  for (gMatVec::Index i=1; i<=N; i++) 
-    for (gMatVec::Index j=1; j<=N+1; j++)
+  for (GNU_gama::Index i=1; i<=N; i++) 
+    for (GNU_gama::Index j=1; j<=N+1; j++)
       A_(M+i, j) = (i==j) ? 1 : 0;
   }
 
@@ -134,11 +134,11 @@ void OLSgso<Float, Exc>::solve_me()
   gso.gso2(); 
 
   this->x.reset(N);
-  for (gMatVec::Index i=1; i<=N; i++)
+  for (GNU_gama::Index i=1; i<=N; i++)
     this->x(i) = A_(M+i, N+1);
 
   this->r.reset(M);
-  for (gMatVec::Index j=1; j<=M; j++)
+  for (GNU_gama::Index j=1; j<=M; j++)
     this->r(j) = A_(j, N+1)/this->sqrt_w(j);
   
   this->is_solved = true; 
@@ -146,43 +146,43 @@ void OLSgso<Float, Exc>::solve_me()
 
 
 template <typename Float, typename Exc>
-Float OLSgso<Float, Exc>::q_xx(gMatVec::Index i, gMatVec::Index j)
+Float OLSgso<Float, Exc>::q_xx(GNU_gama::Index i, GNU_gama::Index j)
   {
     if(!this->is_solved) solve_me();
-    const gMatVec::Index M = this->pA->rows();
-    const gMatVec::Index N = this->pA->cols();
+    const GNU_gama::Index M = this->pA->rows();
+    const GNU_gama::Index N = this->pA->cols();
     i += M;
     j += M;
     Float s = 0;                        
-    for (gMatVec::Index k=1; k<=N; k++) 
+    for (GNU_gama::Index k=1; k<=N; k++) 
       s += A_(i,k)*A_(j,k);              // cov x_i x_j
     return s;
   }
 
 
 template <typename Float, typename Exc>
-Float OLSgso<Float, Exc>::q_bb(gMatVec::Index i, gMatVec::Index j)
+Float OLSgso<Float, Exc>::q_bb(GNU_gama::Index i, GNU_gama::Index j)
   {
     if(!this->is_solved) solve_me();
 
-    const gMatVec::Index N = this->pA->cols();
+    const GNU_gama::Index N = this->pA->cols();
     Float s = 0;                        
-    for (gMatVec::Index k=1; k<=N; k++) 
+    for (GNU_gama::Index k=1; k<=N; k++) 
       s += A_(i,k)*A_(j,k);              // cov b_i b_j
     return s/this->sqrt_w(i)/this->sqrt_w(j);
   }
 
 
 template <typename Float, typename Exc>
-Float OLSgso<Float, Exc>::q_bx(gMatVec::Index i, gMatVec::Index j)
+Float OLSgso<Float, Exc>::q_bx(GNU_gama::Index i, GNU_gama::Index j)
   {
     if(!this->is_solved) solve_me();
 
-    const gMatVec::Index M = this->pA->rows();
-    const gMatVec::Index N = this->pA->cols();
+    const GNU_gama::Index M = this->pA->rows();
+    const GNU_gama::Index N = this->pA->cols();
     j += M;
     Float s = 0;                        
-    for (gMatVec::Index k=1; k<=N; k++) 
+    for (GNU_gama::Index k=1; k<=N; k++) 
       s += A_(i,k)*A_(j,k);              // cov b_i x_j
     return s/this->sqrt_w(i);
   }
