@@ -1,8 +1,8 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.24)
+    C++ Matrix/Vector templates (GNU Gama / matvec 0.9.25)
     Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the gMatVec C++ Matrix/Vector template library.
+    This file is part of the GNU Gama C++ Matrix/Vector template library.
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,18 +20,18 @@
 */
 
 /*
- *  $Id: sortvec.h,v 1.12 2004/08/30 18:18:55 cepek Exp $
+ *  $Id: sortvec.h,v 1.13 2005/03/27 17:43:26 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
-#ifndef gMatVec_Sort_Vec__h_
-#define gMatVec_Sort_Vec__h_
+#ifndef GNU_gama_gMatVec_Sort_Vec__h_
+#define GNU_gama_gMatVec_Sort_Vec__h_
 
 #include <algorithm>
 #include <gmatvec/vecbase.h>
 
 
-namespace gMatVec {
+namespace GNU_gama {
 
 template <typename Float, typename Exc>
 inline void sort(Vec<Float, Exc>& v)
@@ -42,7 +42,7 @@ inline void sort(Vec<Float, Exc>& v)
   }
 
 
-}   // namespace gMatVec
+}   // namespace GNU_gama
 
 #endif
 
