@@ -1,6 +1,6 @@
 /*  
     GNU Gama --- Geodesy and Mapping C++ library 
-    Copyright (C) 1999, 2003  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 1999, 2003, 2005  Ales Cepek <cepek@fsv.cvut.cz>
 
     This file is part of the GNU Gama C++ library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: version.cpp,v 1.51 2004/09/02 13:06:32 cepek Exp $
+ *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
  */
 
 
@@ -28,7 +28,7 @@
 
 namespace GNU_gama {
 
-const char* GNU_gama_version  = "1.7.11";
+const char* GNU_gama_version  = "1.7.12";
 
 const char* GNU_gama_compiler =
               #if   defined (__GNUC__)
@@ -62,6 +62,40 @@ const char* GNU_gama_compiler =
 
 =============================================================================
 
+1.7.12 2005-03-27
+
+    - MatVec templete library moved to namespace GNU_gama
+
+        s/gMatVec/GNU_gama/g
+
+    - a bug in the output of coordiantes in the XML format
+
+        diff -r1.6 coordinates.h
+        68c68,69
+        <         if (!b.active_xy()) continue;
+        ---
+        >         if (!b.active_xy() && !b.active_z()) continue;
+        > 
+
+    - a bug in the second GSO constructor
+
+        <  *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
+        ---
+        >  *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
+        80,83c80
+        <   GSO(Mat<Float, Exc>& a, Index m, Index n)
+        <     : pA(0), M(0), N(0), sc(true), tol_(0),
+        <     minx_n(0), minx(0), clist(0), rlist(0) 
+        <   { 
+        ---
+        >   GSO(Mat<Float, Exc>& a, Index m, Index n) : sc(true), tol_(0) { 
+        122,125d118
+        <   template <typename T> inline const T ABS(const T& x)
+        <     {
+        <       return (x >= T(0)) ? x : -x ;
+        <     }
+
+
 1.7.11 2004-09-02
 
     - simplified version of GNU_gama::List<> template
